package com.steerinfo.dil.controller;

import com.steerinfo.dil.mapper.AmsRailOffsetDayplanMapper;
import com.steerinfo.dil.model.AmsRailOffsetDayplan;
import com.steerinfo.dil.service.impl.AmsRailOffsetDayplanServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/${api.version}/amsrailoffsetdayplan")
public class AmsRailOffsetDayplanController extends BaseRESTfulController {
    @Autowired
    AmsRailOffsetDayplanServiceImpl amsRailOffsetDayplanService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    AmsRailOffsetDayplanMapper amsRailOffsetDayplanMapper;


    @ApiModelProperty(value = "新增钢材发往异地库计划")
    @PostMapping("/addRailOffsetDayplan")
    public RESTfulResult addRailOffsetDayplan(@RequestBody Map<String,Object> mapValue) {
        int result = amsRailOffsetDayplanService.insert(mapValue);
        return success(result);
    }


    @ApiModelProperty(value = "修改渲染")
    @PostMapping("/getRailOffseDayMes/{dayplanId}")
    public RESTfulResult getRailOffseDayMes(@PathVariable("dayplanId") Integer dayplanId) {
        List<Map<String, Object>> mes = amsRailOffsetDayplanMapper.getRailOffseDayMes(dayplanId);
        return success(mes);
    }

    @ApiModelProperty(value = "通过发运计划主键查询关联所有物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "362", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getMaterialMesByDayPlanId")
    public RESTfulResult getMaterialMesByDayPlanId(@RequestBody(required = false) Map<String,Object> mapValue,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   Integer apiId,
                                                   @RequestParam Integer dayplanId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        mapValue.put("dayplanId",dayplanId);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsRailOffsetDayplanService.getMaterialMesByDayPlanId(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }

    @ApiModelProperty(value = "删除钢材发往异地库计划")
    @PostMapping("/deleteRailOffsetDayplan/{dayplanId}")
    public RESTfulResult deleteTruckRailDayPlan(@PathVariable("dayplanId") Integer dayplanId) {
        int result = amsRailOffsetDayplanService.deleteTruckRailDayPlan(new BigDecimal(dayplanId));
        return success(result);
    }

    @ApiModelProperty(value = "修改钢材发往异地库计划")
    @PostMapping("/updateRailOffsetDayplan")
    public RESTfulResult updateRailOffsetDayplan(@RequestBody AmsRailOffsetDayplan amsRailOffsetDayplan) {
        if(amsRailOffsetDayplan.getDayplanId()==null){
            return failed("传值为空");
        }
        amsRailOffsetDayplanService.update(amsRailOffsetDayplan);
        return success("修改成功");
    }

    @ApiModelProperty(value = "下发钢材发往异地库计划")
    @PostMapping("/issueRailOffsetDayplan")
    public RESTfulResult issueRailOffsetDayplan(@RequestBody List<Map<String,Object>> mapList) {
        int result = amsRailOffsetDayplanService.issueRailOffsetDayplan(mapList);
        return success(result);
    }

    @ApiModelProperty(value = "接收钢材发往异地库计划")
    @PostMapping("/receiveRailOffsetDayplan/{dayplanId}")
    public RESTfulResult receiveRailOffsetDayplan(@PathVariable("dayplanId") Integer dayplanId) {
        int result = amsRailOffsetDayplanService.receiveRailOffsetDayplan(dayplanId);
        return success(result);
    }

    /**
     * 查询钢材发往异地库计划
     */
    @ApiModelProperty(value = "展示钢材发往异地库计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "183", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getRailOffsetDayplan")
    public RESTfulResult getRailOffsetDayplan(@RequestBody(required = false) Map<String,Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId,
                                              Integer dayplanReceiveStatus,
                                              Integer carrierId
                                              ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        if (carrierId != null && !"undefined".equals(carrierId.toString())) {
            mapValue.put("carrierId", new BigDecimal(carrierId));
        }
        mapValue.put("dayplanReceiveStatus",new BigDecimal(dayplanReceiveStatus));
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsRailOffsetDayplanService.getRailOffsetDayplan(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }

    @PostMapping("/getRailOffsetDayplanId")
    public RESTfulResult getRailOffsetDayplanId(@RequestBody(required = false) Map<String,Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId,
                                              Integer dayPlanId
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }

        mapValue.put("dayPlanId",new BigDecimal(dayPlanId));
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amsRailOffsetDayplanService.getRailOffsetDayplanId(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }

    /**
     * 到站下拉
     * @return
     */
    @GetMapping("/getdayPlanToTheStationId")
    public RESTfulResult getdayPlanToTheStationId() {
        List<Map<String,Object>> mapList = amsRailOffsetDayplanService.getdayPlanToTheStationId();
        return success(mapList);
    }

}
