package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ColumnDataFeign;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.service.IAmstruckSporadicOrderService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.text.SimpleDateFormat;
import java.util.List;
import java.util.Map;


/**
 * AmstruckSporadicOrder RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-16 02:49
 * 类描述
 * 修订历史：
 * 日期：2021-12-16
 * 作者：generator
 * 参考：
 * 描述：AmstruckSporadicOrder RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amstrucksporadicorders")
public class AmstruckSporadicOrderController extends BaseRESTfulController {

    @Autowired
    IAmstruckSporadicOrderService amstruckSporadicOrderService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ColumnDataFeign columnDataFeign;
    @Autowired
    ESFeign esFeign;

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    @ApiOperation(value="新增零星物资进出厂（以及销售钢材退货）,包括内转精煤")
    @PostMapping("/addSporadicOrders")
    public RESTfulResult addSporadicOrders(@RequestBody Map<String,Object> mapValue) {
        int result = amstruckSporadicOrderService.addSporadicOrder(mapValue);
        return success(result);
    }

    @ApiOperation(value="下发零星物资订单")
    @PostMapping("/issueSporadicOrders")
    public RESTfulResult issueSporadicOrders(@RequestBody List<Map<String, Object>> mapList) {
        int result = amstruckSporadicOrderService.issueSporadicOrders(mapList);
        return success(result);
    }

    @ApiOperation(value="逻辑删除零星物资订单")
    @PostMapping("/deleteSporadicOrders")
    public RESTfulResult deleteSporadicOrders(@RequestParam Integer sporadicOrderId) {
        int result = amstruckSporadicOrderService.deleteSporadicOrders(sporadicOrderId);
        return success(result);
    }

    @ApiOperation(value="查询零星物资订单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "384", required = false, dataType = "Integer")
    })
    @PostMapping("/getSporadicOrdersList")
    public RESTfulResult getSporadicOrdersList(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer orderType,
                                               Integer issueStatus,
                                               String con,
                                               Integer dispatchStatus,
                                               Integer sporadicStatus,
                                               String carrierSsoId,
                                               String userId,
                                               String userIds,
                                               String startTime,
                                               String endTime
                                               ) {

        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        if (orderType!=null){
            mapValue.put("orderType",orderType);
        }
        if (issueStatus!=null){
            mapValue.put("issueStatus",issueStatus);
        }
        if (dispatchStatus!=null){
            mapValue.put("dispatchStatus",dispatchStatus);
        }
        if (sporadicStatus!=null){
            mapValue.put("sporadicStatus",sporadicStatus);
        }
        if (carrierSsoId!=null){
            mapValue.put("carrierSsoId",carrierSsoId);
        }
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        if(con != null && !"null".equals(con)){
            mapValue.put("con","%" + con + "%");
        }
        PageHelper.startPage(pageNum,pageSize);
        List<Map<String, Object>> columnList = amstruckSporadicOrderService.getSporadicOrdersList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,columnList);
        return success(pageList);
    }

    @ApiOperation(value="查看物资详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "385", required = false, dataType = "Integer")
    })
    @PostMapping("/seeAllMaterials")
    public RESTfulResult seeAllMaterials(@RequestBody(required = false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer sporadicOrderId,
                                         String con,
                                         String userId,
                                         String userIds) {
        if (userId!=null){
            mapValue.put("userId",userId);
        }
        if (userIds!=null){
            mapValue.put("userIds",userIds);
        }
        if (sporadicOrderId!=null) {
            mapValue.put("sporadicOrderId", sporadicOrderId);
        }
        PageHelper.startPage(pageNum,pageSize);
        List<Map<String, Object>> columnList = amstruckSporadicOrderService.seeAllMaterials(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,columnList);
        return success(pageList);
    }

    @ApiOperation(value="修改零星物资订单")
    @PostMapping("/updateSporadicOrder")
    public RESTfulResult updateSporadicOrder(@RequestBody Map<String,Object> mapValue) {
        int result = amstruckSporadicOrderService.updateSporadicOrder(mapValue);
        return success(result);
    }

    @ApiOperation(value="查询修改渲染")
    @PostMapping("/selectSporadicOrder")
    public RESTfulResult selectSporadicOrder(@RequestParam Integer sporadicOrderId) {
        List<Map<String, Object>> mapList = amstruckSporadicOrderService.selectSporadicOrder(sporadicOrderId);
        return success(mapList);
    }



    @ApiOperation(value="零星一车多趟新增订单")
    @PostMapping("/addSporadicOrderTimes")
    public RESTfulResult addSporadicOrderTimes(@RequestBody Map<String,Object> map) {
       int i=amstruckSporadicOrderService.addSporadicOrderforTimes(map);
        return success(i);
    }

    @ApiOperation(value = "停止零星订单一车多趟")
    @PostMapping("/closeSporadicOrder")
    public RESTfulResult closeSporadicOrder(@RequestBody Map<String,Object> map) {
        int i=amstruckSporadicOrderService.closeSporadic(map);
        return success(i);
    }


    @ApiOperation(value = "内转零星运输计划")
    @PostMapping("/addInwardSporadicOrder")
    public RESTfulResult addInwardSporadicOrder(@RequestBody Map<String,Object> map) {
        int i=amstruckSporadicOrderService.addInwardSporadicOrder(map);
        return success(i);
    }

    @ApiOperation(value = "查运输订单物资详情")
    @PostMapping("/getSporadic")
    public RESTfulResult getSporadic(Integer sporadicId) {
        return success(amstruckSporadicOrderService.getSporadic(sporadicId));
    }

    @ApiOperation(value = "查零星订单物资详情")
    @PostMapping("/getSporadicOfOrder")
    public RESTfulResult getSporadicOfOrder(@RequestBody(required = false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer sporadicId
                                            ) {
        mapValue.put("sporadicId",sporadicId);
        PageHelper.startPage(pageNum,pageSize);
        List<Map<String, Object>> columnList = amstruckSporadicOrderService.getSporadicOfOrder(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,columnList);
        return success(pageList);
    }

}
