package com.steerinfo.dil.mapper;

import com.steerinfo.dil.model.AmsSaleOrder;
import com.steerinfo.framework.mapper.IBaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

@Mapper
public interface AmsSaleOrderMapper extends IBaseMapper<AmsSaleOrder, BigDecimal> {
    //查询所有未上报销售订单信息
    List<Map<String, Object>> getSaleOrderInfo(Map<String,Object> map);
    //查询所有已上报销售订单信息
    List<Map<String, Object>> getSaleOrderReported(Map<String,Object> map);
    //根据车序号查询销售订单详细
    List<Map<String, Object>> getSaleOrderDetail(Map<String,Object> map);
    //获取销售计划名称
    List<Map<String, Object>> getSalePlanName();
    //获取发货单位
    List<Map<String, Object>> getShipperName();
    //获取收货单位
    List<Map<String, Object>> getConsigneeCompanyName();
    //查询主键最大值
    @Select("select seq_AMS_SALE_ORDER.nextval from dual")
    BigDecimal selectMaxId();
    //获取要渲染的数据
    List<Map<String, Object>> selectBySaleOrderId(BigDecimal saleOrderId);
    //删除所有从表信息
    int deleteBySaleOrderId(BigDecimal saleOrderId);
    //查询所有财务已经审批的销售订单
    List<Map<String, Object>> getAmsSaleOrderApproved(Map<String,Object> map);
    //通过销售订单号查询销售订单的修改日志
    List<Map<String, Object>> getSaleOrderUpdateLog(Map<String,Object> map);

    List<Map<String,Object>> getSaleOrderList(Map<String,Object> mapValue);
    //获取销售公司已审核的订单
    List<Map<String,Object>> getSaleOrderListBySaleCompany(Map<String,Object> map);

    //通过地址Id查询承运商ID
    List<Integer>  getCarrier(Integer param);

    //根据销售订单id查找信息
    Map<String,Object>  selectInfoBySaleOrderId(BigDecimal saleOrderId);

    //根据销售订单id查找物资信息，渲染数据
    List<Map<String,Object>> selectMaterialInfoBySaleOrderId(BigDecimal saleOrderId);

    //根据销售订单id查找车序号id和车序号与物资中间表主键
    List<Map<String,Object>> selectSaleOrderMaterialIdBySaleOrderId(BigDecimal saleOrderId);
    //根据中标区域省市县查询承运商id
    BigDecimal selectCarrierIdByprovince(Map<String,Object> map);
    //根据收货地址id查询省市县
    Map<String,Object> selectProvince(Integer addressId);
    //查询未上报的销售订单信息
    List<Map<String, Object>> getSaleOrderInfoes(Map<String,Object> map);
    //查询已上报销售订单信息
    List<Map<String, Object>> getSaleOrderReportedes(Map<String,Object> map);
    //获取销售公司已审核的订单
    List<Map<String,Object>> getSaleOrderListBySaleCompanyes(Map<String,Object> map);
    //查询财务已经审批的销售订单
    List<Map<String, Object>> getAmsSaleOrderApprovedes(Map<String,Object> map);

    // 根据销售订单主键展示销售基本信息、物资信息
    List<Map<String, Object>> getSaleOrderAndMaterialById(Map<String,Object> mapValue);

    // 销售订单物资
    List<Map<String, Object>> getSaleMaterial(Map<String,Object> loserMap);

    // 销售焦炭订单
    List<Map<String, Object>> getCokeSaleOrderList(Map<String,Object> mapValue);

    // 得到销售订单已计量的重量
    BigDecimal getNetWeight(BigDecimal saleOrderId);

    // 得到销售订单已分配的车数
    BigDecimal getCarNum(BigDecimal saleOrderId);
    // 查询销售订单下的车序号和物资
    List<Map<String, Object>> getTruckNoAndMaterial(Map<String,Object> map);
    // 根据详细地址匹配省市县
    BigDecimal getAddressByPlace(BigDecimal placeId);
    // 根据省市县匹配承运商
    List<Map<String, Object>> getCarrierByPlace(BigDecimal placeId);
    // 根据详细地址匹配承运商
    Map<String, Object> getPriceByCarrierAndPlace(Map<String, Object> mapValue);

    List<Map<String, Object>> getSaleOrderListToCarrier(Map<String, Object> mapValue);
    // 展示未匹配承运商的车序号
    List<Map<String, Object>> getSteelTruckNoList(Map<String, Object> mapValue);
    // 车序号下的物资
    List<Map<String, Object>> getTruckNoMaterial(BigDecimal saleOrderMaterialId);

    List<Map<String, Object>> getCarrierTruckNoList(Map<String, Object> mapValue);
    List<Map<String, Object>> getTruckNoMaterialAndCarrier(BigDecimal saleOrderMaterialId);
    // 展示已派车的车序号
    List<Map<String, Object>> getHaveCarTruckNoList(Map<String, Object> mapValue);

    List<Map<String, Object>> getSaleOrderListByCarrierSsoId(Map<String, Object> map);

    BigDecimal getOrderPrice(Map<String, Object> map);
    // 根据id查询收货单位名称
    String selectConsigneeName(BigDecimal receiveId);
    // 根据收货单位名称查询承运商id
    BigDecimal selectCarrierId(String consigneeName);
    // 查询销售订单的数据
    Map<String, Object> getSaleMapMessages(BigDecimal saleOrderId);
    // 查询销售订单下面表的数据
    List<Map<String, Object>> getSaleListMessages(BigDecimal saleOrderId);
    // 自动匹配出最近的一个地址
    List<Map<String, Object>> matchingAddressRecently(BigDecimal receiveId);
    // 自动匹配出最近的一个销售员
    List<Map<String, Object>> getSalerByReceiveId(BigDecimal receiveId);
    // 自动匹配上一条运单的司机电话
    String matchingDriverTelRecently(String capacityNumber);
    // 查询内转焦炭订单
    List<Map<String,Object>> getCokeInwardOrderList(Map<String, Object> mapValue);
    // 得到定向派单表id
    BigDecimal getDispatchId(BigDecimal saleOrderMaterialId);
    // 得到销售订单物资表主键
    List<Map<String, Object>> getSaleMaterialId(BigDecimal saleOrderMaterialId);
    // 得到销售订单物资的集合
    List<Map<String, Object>> getSaleList(Map<String,Object> truckNoMap);
    // 副产品订单
    List<Map<String, Object>> getFuSaleOrderList(Map<String,Object> truckNoMap);
    // 副产品关闭未进厂的运单
    int closeOrderNotIn(BigDecimal saleOrderId);
    // 展示反审批的销售订单
    List<Map<String, Object>> getSteelOrderDeletedList(Map<String,Object> mapValue);
    // 展示所有状态销售订单列表
    List<Map<String, Object>> getAllSteelSaleOrderList(Map<String, Object> mapValue);
    // 修改厂内未装货车辆的运单车牌号
    int updateCapacityNumberInFactory(Map<String, Object> mapValue);
    // 根据省市县id匹配承运商
    List<Map<String, Object>> getCarrierByAddress(BigDecimal addressId);

    List<Map<String, Object>> getSaleCokeOrder(Map<String, Object> mapValue);
    Integer findStatus(BigDecimal saleOrderMaterialId);

    BigDecimal getPlaceId(BigDecimal saleOrderMaterialId);

    List<Map<String, Object>> getAddressPriceList(Map<String, Object> hashMap);

    String findSelfMention(BigDecimal saleOrderMaterialId);

    BigDecimal findReceiveId(Object receiveName);

    BigDecimal findSalerId(Object salerName);

    BigDecimal findMaterialId(Map<String, Object> materialMap);

    BigDecimal findAddressId(Map<String, Object> addressMap);

    Map<String, Object> getSaleMaterialMessage(BigDecimal saleMaterialId);

    int findOrderMaxNum(BigDecimal resultTotalId);

    List<Map<String, Object>> getKucunList(Map<String, Object> map);

}