package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.AmsSalePlanMapper;
import com.steerinfo.dil.mapper.AmsSalePlanMaterialMapper;
import com.steerinfo.dil.model.AmsSalePlan;
import com.steerinfo.dil.model.AmsSalePlanMaterial;
import com.steerinfo.dil.service.IAmsSalePlanService;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * AmsSalePlan服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-06 07:10
 * 类描述
 * 修订历史：
 * 日期：2021-09-06
 * 作者：generator
 * 参考：
 * 描述：AmsSalePlan服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amsSalePlanService")
public class AmsSalePlanServiceImpl implements IAmsSalePlanService {

    @Autowired
    private AmsSalePlanMapper amsSalePlanMapper;

    @Autowired
    private AmsSalePlanMaterialMapper amsSalePlanMaterialMapper;

    @Override
    public int deleteAmsSalePlan(BigDecimal planId) {
        AmsSalePlan amsSalePlan = amsSalePlanMapper.selectByPrimaryKey(planId);
        amsSalePlan.setDeleted(new BigDecimal(1));
        return amsSalePlanMapper.updateByPrimaryKey(amsSalePlan);
    }

    /**
     * 查询所有的钢材物资
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getAllSteelMaterialMes(Map<String, Object> map) {
        return amsSalePlanMapper.getAllSteelMaterialMes(map);
    }

    @Override
    public List<Map<String, Object>> getSalePlanInfo(Map<String, Object> map) {
        return amsSalePlanMapper.getSalePlanInfo(map);
    }

    @Override
    public int addAmsSalePlan(Map<String, Object> map) throws Exception {
        Map<String,Object> map1 = (Map<String, Object>) map.get("amsSalePlan");
        long planDate = (long) map1.get("planDate");
        Date planDate1 = new Date(planDate);
        Integer saleAreaId = (Integer) map1.get("saleAreaId");
        String insertUsername = (String) map1.get("insertUsername");
        long insertTime = (long) map1.get("insertTime");
        Date insertTime1 = new Date(insertTime);
        String insertUpdateRemark = (String) map1.get("insertUpdateRemark");
        AmsSalePlan amsSalePlan = new AmsSalePlan();
        amsSalePlan.setPlanDate(planDate1);
        amsSalePlan.setSaleAreaId(new BigDecimal(saleAreaId));
        amsSalePlan.setInsertUsername(insertUsername);
        amsSalePlan.setInsertTime(insertTime1);
        amsSalePlan.setInsertUpdateRemark(insertUpdateRemark);
        List<Map<String,Object>> selectionList = (List<Map<String, Object>>) map.get("selectionList");
        //新增销售计划
        long id;
        if(amsSalePlanMapper.selectMaxId()==null){
            id = 1;
        }else {
            id = amsSalePlanMapper.selectMaxId().longValue()+1;
        }
        //生成主键id
        amsSalePlan.setPlanId(new BigDecimal(id));
        //获取销售片区名
        BigDecimal areaId = amsSalePlan.getSaleAreaId();
        String areaName = amsSalePlanMapper.getAreaNameByAreaId(areaId);
        //获取计划日期
        Date planDate2 = amsSalePlan.getPlanDate();
        SimpleDateFormat simpleDateFormat1 = new SimpleDateFormat("yyyy-MM-dd");
        String DateString = simpleDateFormat1.format(planDate2);
        //拼接片区名和日期
        String PlanName = areaName + DateString;
        amsSalePlan.setPlanName(PlanName);
        amsSalePlan.setUpdateUsername("admin");
        amsSalePlan.setUpdateTime(new Date());
        amsSalePlan.setDeleted(new BigDecimal(0));
        //新增
        int i = amsSalePlanMapper.insert(amsSalePlan);
        if(i==1){
            for (Map<String, Object> stringObjectMap : selectionList) {
                Integer materialId = (Integer) stringObjectMap.get("materialId");
                Integer materialNumber = (Integer) stringObjectMap.get("orderPlanWeight");
                AmsSalePlanMaterial amsSalePlanMaterial =new AmsSalePlanMaterial();
                amsSalePlanMaterial.setSalePlanId(new BigDecimal(id));
                amsSalePlanMaterial.setMaterialId(new BigDecimal(materialId));
                amsSalePlanMaterial.setMaterialNumber(new BigDecimal(materialNumber));
                addAmsSalePlanMaterial(amsSalePlanMaterial);
            }
        }
        return i;
    }

    //新增销售计划物资信息
    public int addAmsSalePlanMaterial(AmsSalePlanMaterial amsSalePlanMaterial) {
        long id;
        if(amsSalePlanMaterialMapper.selectMaxId()==null){
            id = 1;
        }else {
            id = amsSalePlanMaterialMapper.selectMaxId().longValue()+1;
        }
        //生成主键id
        amsSalePlanMaterial.setPlanMaterialId(new BigDecimal(id));
        //常规字段
        amsSalePlanMaterial.setInsertUsername("admin");
        amsSalePlanMaterial.setInsertTime(new Date());
        amsSalePlanMaterial.setUpdateUsername("admin");
        amsSalePlanMaterial.setUpdateTime(new Date());
        amsSalePlanMaterial.setInsertUpdateRemark("无");
        return amsSalePlanMaterialMapper.insert(amsSalePlanMaterial);
    }

    @Override
    public List<Map<String, Object>> getMaterialName() {
        return amsSalePlanMapper.getMaterialName();
    }

    @Override
    public List<Map<String, Object>> getAreaName() {
        return amsSalePlanMapper.getAreaName();
    }

    @Override
    public List<Map<String, Object>> selectByPlanId(BigDecimal planId) {
        return amsSalePlanMapper.selectByPlanId(planId);
    }

    @Override
    public int updateAmsSalePlan(AmsSalePlan amsSalePlan) {
        amsSalePlan.setUpdateTime(new Date());
        return amsSalePlanMapper.updateByPrimaryKeySelective(amsSalePlan);
    }
}
