package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.*;
import com.steerinfo.dil.model.*;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.service.IAmstruckSporadicOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * AmstruckSporadicOrder服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-16 02:49
 * 类描述
 * 修订历史：
 * 日期：2021-12-16
 * 作者：generator
 * 参考：
 * 描述：AmstruckSporadicOrder服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amstruckSporadicOrderService")
public class AmstruckSporadicOrderServiceImpl implements IAmstruckSporadicOrderService {

    @Autowired
    private AmstruckSporadicOrderMapper amstruckSporadicOrderMapper;
    @Autowired
    OmstruckOrderMapper omstruckOrderMapper;
    @Autowired
    OmstruckOrderMaterialMapper omstruckOrderMaterialMapper;
    @Autowired
    TmstruckTotalResultMapper tmstruckTotalResultMapper;
    @Autowired
    AmstruckSporadicMaterialMapper amstruckSporadicMaterialMapper;

    /**
     * 新增零星物资进出厂（以及销售钢材退货）
     * @param mapValue
     * @return
     * mapvalue所需值：number(趟次)，supplierId(发货单位)，receiveId（收货单位），carrierId(承运商)，
     * orderType（订单类型）,lineId(运输路径),materialId(物资），orderMaterialNumber（物资件数）
     * materialPriority(装货优先级)
     * orderType:15 内转其他物资进厂需要趟次 16
     * 内转其他物资出厂需要趟次
     * modifier：zx
     */
    @Transactional
    @Override
    public int addSporadicOrders(Map<String, Object> mapValue) {
            int result = 0;
            // 新增零星订单表
            // 发货单位
            BigDecimal sendUnit = new BigDecimal((Integer) mapValue.get("supplierId"));
            // 收货单位
            BigDecimal receiveUnitId = new BigDecimal((Integer) mapValue.get("receiveId"));
            // 承运商
            BigDecimal carrierId = new BigDecimal((Integer) mapValue.get("carrierId"));
            // 得到订单类型
            BigDecimal orderType = new BigDecimal((Integer) mapValue.get("orderType"));
            // 得到运输路径
            BigDecimal lineId = new BigDecimal((Integer) mapValue.get("lineId"));
            String userId=(String) mapValue.get("userId");
            // 获取主键id
            BigDecimal sporadicOrderId = amstruckSporadicOrderMapper.selectSporadicOrderId();
            AmstruckSporadicOrder amstruckSporadicOrder = new AmstruckSporadicOrder();
            // 设置零星物流主键
            amstruckSporadicOrder.setSporadicOrderId(sporadicOrderId);
            // 设置零星物流编号
            amstruckSporadicOrder.setSporadicOrderNo(DataChange.generateEightDigitsNumber("WLXDD", sporadicOrderId.intValue()));
            // 设置发货单位
            amstruckSporadicOrder.setSendUnitId(sendUnit);
            // 设置收货单位
            amstruckSporadicOrder.setReceiveUnitId(receiveUnitId);
            // 设置承运商
            // 判断承运商是否为空
            if (carrierId!=null) {
               amstruckSporadicOrder.setCarrierId(carrierId);
           }
            // 设置下发状态
            amstruckSporadicOrder.setIssueStatus(new BigDecimal(0));
            amstruckSporadicOrder.setInsertTime(new Date());
            amstruckSporadicOrder.setInsertUsername("admin");
            amstruckSporadicOrder.setDeleted(new BigDecimal(0));
            amstruckSporadicOrder.setInsertUpdateRemark("无");
            List<Map<String, Object>> mapList = (List<Map<String, Object>>) mapValue.get("mapList");
            // 新增运输订单表
            OmstruckOrder omstruckOrder = new OmstruckOrder();
            BigDecimal orderId = omstruckOrderMapper.selectMaxId();
            omstruckOrder.setOrderId(orderId);
            omstruckOrder.setOrderPlanId(sporadicOrderId);
            omstruckOrder.setOrderNumber(DataChange.generateEightDigitsNumber("WYSDD", orderId.intValue()));
            omstruckOrder.setOrderType(orderType);
            omstruckOrder.setInsertTime(new Date());
            omstruckOrder.setInsertUsername(userId);
            omstruckOrder.setInsertUpdateRemark("无");
            omstruckOrder.setLineId(lineId);
            // 新增总实绩id
            TmstruckTotalResult tmstruckTotalResult = new TmstruckTotalResult();
            tmstruckTotalResult.setResultTotalId(tmstruckTotalResultMapper.selectTmstruckTotalResultId());
            tmstruckTotalResult.setOrderId(omstruckOrder.getOrderId());
            // 新增总实绩
            result += tmstruckTotalResultMapper.insertSelective(tmstruckTotalResult);
            result += amstruckSporadicOrderMapper.insertSelective(amstruckSporadicOrder);
            result += omstruckOrderMapper.insertSelective(omstruckOrder);
            for (Map<String, Object> map : mapList) {
                BigDecimal materialId = new BigDecimal((Integer) map.get("materialId"));
                BigDecimal materialWeight = DataChange.dataToBigDecimal(map.get("orderMaterialWeight"));
                BigDecimal materialNumber = DataChange.dataToBigDecimal(map.get("orderMaterialNumber"));
                OmstruckOrderMaterial omstruckOrderMaterial = new OmstruckOrderMaterial();
                BigDecimal orderMaterialId = omstruckOrderMaterialMapper.selectMaxId();
                omstruckOrderMaterial.setOrderMaterialId(orderMaterialId);
                omstruckOrderMaterial.setOrderId(orderId);
                omstruckOrderMaterial.setMaterialId(materialId);
                    //设置物资装货优先级
                    omstruckOrderMaterial.setMaterialPriority(DataChange.dataToBigDecimal(map.get("materialPriority")));
                    omstruckOrderMaterial.setInsertUsername("admin");
                    omstruckOrderMaterial.setInsertTime(new Date());
                    if (materialWeight != null) {
                        omstruckOrderMaterial.setOrderMaterialWeight(materialWeight);
                    }
                    if (materialNumber != null) {
                        omstruckOrderMaterial.setOrderMaterialNumber(materialNumber);
                    }
                    result += omstruckOrderMaterialMapper.insertSelective(omstruckOrderMaterial);
                }
            return result;
        }


    /**
     * 新增零星物资一车多趟
     * @param map
     * @return
     * author：zx
     */
    @Transactional
    @Override
    public int addSporadicOrdersForCoke(Map<String, Object> map) {
        int result = 0;
        // 新增零星订单表
        // 发货单位
        BigDecimal sendUnit = new BigDecimal((Integer) map.get("supplierId"));
        // 收货单位
        BigDecimal receiveUnitId = new BigDecimal((Integer) map.get("receiveId"));
        // 得到订单类型
        BigDecimal orderType = new BigDecimal((Integer) map.get("orderType"));
        // 获取用户id
        String userId=(String) map.get("userId");
        // 得到运输路径
        BigDecimal lineId = new BigDecimal((Integer) map.get("lineId"));
        BigDecimal sporadicOrderId = amstruckSporadicOrderMapper.selectSporadicOrderId();
        AmstruckSporadicOrder amstruckSporadicOrder = new AmstruckSporadicOrder();
        amstruckSporadicOrder.setSporadicOrderId(sporadicOrderId);
        amstruckSporadicOrder.setSporadicOrderNo(DataChange.generateEightDigitsNumber("WLXDD", sporadicOrderId.intValue()));
        amstruckSporadicOrder.setSendUnitId(sendUnit);
        amstruckSporadicOrder.setReceiveUnitId(receiveUnitId);
        //新增初始化已运输趟次
        amstruckSporadicOrder.setSporadicTransTimes(new BigDecimal(0));
        // 设置趟次
        BigDecimal orderTime=DataChange.dataToBigDecimal(map.get("orderTime"));
        if (orderTime!=null) {
            amstruckSporadicOrder.setSporadicOrderTimes(DataChange.dataToBigDecimal(orderTime));
        }
        //设置运输状态
        amstruckSporadicOrder.setTransStatus(DataChange.dataToBigDecimal(map.get("isMoreTrips")));
        if (map.get("carrierId")!=null) {
            amstruckSporadicOrder.setCarrierId(DataChange.dataToBigDecimal(map.get("carrierId")));
        }
        amstruckSporadicOrder.setIssueStatus(new BigDecimal(0));
        amstruckSporadicOrder.setInsertTime(new Date());
        amstruckSporadicOrder.setInsertUsername(userId);
        amstruckSporadicOrder.setDeleted(new BigDecimal(0));
        amstruckSporadicOrder.setInsertUpdateRemark("无");
        amstruckSporadicOrder.setDispatchStatus(new BigDecimal(0));
        List<Map<String, Object>> mapList = (List<Map<String, Object>>) map.get("mapList");
        // 新增运输订单表
        OmstruckOrder omstruckOrder = new OmstruckOrder();
        BigDecimal orderId = omstruckOrderMapper.selectMaxId();
        omstruckOrder.setOrderId(orderId);
        omstruckOrder.setOrderPlanId(sporadicOrderId);
        //生成运输订单
        omstruckOrder.setOrderNumber(DataChange.generateEightDigitsNumber("WYSDD", orderId.intValue()));
        omstruckOrder.setOrderType(orderType);
        omstruckOrder.setInsertTime(new Date());
        omstruckOrder.setInsertUsername(userId);
        omstruckOrder.setInsertUpdateRemark("无");
        omstruckOrder.setLineId(lineId);
        if (map.get("carrierId")!=null) {
            omstruckOrder.setCarrierId(DataChange.dataToBigDecimal(map.get("carrierId")));
        }
        //新增总实绩id
        TmstruckTotalResult tmstruckTotalResult = new TmstruckTotalResult();
        tmstruckTotalResult.setResultTotalId(tmstruckTotalResultMapper.selectTmstruckTotalResultId());
        tmstruckTotalResult.setOrderId(omstruckOrder.getOrderId());
        //新增总实绩
        result += tmstruckTotalResultMapper.insertSelective(tmstruckTotalResult);
        result += amstruckSporadicOrderMapper.insertSelective(amstruckSporadicOrder);
        result += omstruckOrderMapper.insertSelective(omstruckOrder);
        for (Map<String, Object> map1 : mapList) {
            BigDecimal materialId = new BigDecimal((Integer) map1.get("materialId"));
            BigDecimal materialWeight = DataChange.dataToBigDecimal(map1.get("orderMaterialWeight"));
            BigDecimal materialNumber = DataChange.dataToBigDecimal(map1.get("orderMaterialNumber"));
            OmstruckOrderMaterial omstruckOrderMaterial = new OmstruckOrderMaterial();
            BigDecimal orderMaterialId = omstruckOrderMaterialMapper.selectMaxId();
            omstruckOrderMaterial.setOrderMaterialId(orderMaterialId);
            omstruckOrderMaterial.setOrderId(orderId);
            omstruckOrderMaterial.setMaterialId(materialId);
            //设置物资装货优先级
            BigDecimal materialPriority=DataChange.dataToBigDecimal(map1.get("materialPriority"));
            //判断装卸货优先级是否为空
            if (materialPriority!=null) {
                omstruckOrderMaterial.setMaterialPriority(DataChange.dataToBigDecimal(map1.get("materialPriority")));
            }else {
                omstruckOrderMaterial.setMaterialPriority(new BigDecimal(1));
            }
            omstruckOrderMaterial.setInsertUsername(userId);
            omstruckOrderMaterial.setInsertTime(new Date());
            if (materialWeight != null) {
                omstruckOrderMaterial.setOrderMaterialWeight(materialWeight);
            }
            if (materialNumber != null) {
                omstruckOrderMaterial.setOrderMaterialNumber(materialNumber);
            }
            result += omstruckOrderMaterialMapper.insertSelective(omstruckOrderMaterial);
            //新增零星订单子表
            AmstruckSporadicMaterial amstruckSporadicMaterial=new AmstruckSporadicMaterial();
            amstruckSporadicMaterial.setSporadicOrderMaterialId(amstruckSporadicMaterialMapper.getSporadicMaterial());
            amstruckSporadicMaterial.setSporadicOrderId(amstruckSporadicOrder.getSporadicOrderId());
            amstruckSporadicMaterial.setMaterialId(materialId);
            amstruckSporadicMaterial.setMaterialWeight(DataChange.dataToBigDecimal(materialWeight));
            amstruckSporadicMaterial.setMaterialNumber(DataChange.dataToBigDecimal(materialNumber));
            amstruckSporadicMaterial.setInsertTime(new Date());
            amstruckSporadicMaterial.setInsertUsername(userId);
            result += amstruckSporadicMaterialMapper.insertSelective(amstruckSporadicMaterial);
        }
            return result;
    }

   //添加零星物资
    @Override
    public int addSporadicOrder(Map<String, Object> map) {
        Integer orderType =(Integer) map.get("orderType");
        switch (orderType){
            case 12:
            case 13:
            case 14:
            case 19:
                addSporadicOrdersForCoke(map);

        }
        return 1;
    }

    @Override
    public int addInwardSporadicOrder(Map<String, Object> map) {
        int result=0;
        BigDecimal sporadicOrderId = DataChange.dataToBigDecimal(map.get("sporadicOrderId"));
        String userId=(String)map.get("userId");
        //添加承运商
        AmstruckSporadicOrder amstruckSporadicOrder=new AmstruckSporadicOrder();
        amstruckSporadicOrder.setSporadicOrderId(sporadicOrderId);
        amstruckSporadicOrder.setCarrierId(DataChange.dataToBigDecimal(map.get("carrierId")));
        amstruckSporadicOrder.setUpdateUsername(userId);
        amstruckSporadicOrder.setInsertTime(new Date());
        result += amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
        return result ;
    }

    /**
     * 下发零星物资订单
     * @param mapList
     * @return
     */
    @Override
    public int issueSporadicOrders(List<Map<String, Object>> mapList) {
        int result = 0;
        // 遍历
        for (Map<String, Object> map : mapList) {
            //零星订单修改订单状态
            OmstruckOrder omstruckOrder=new OmstruckOrder();
            omstruckOrder.setOrderId(DataChange.dataToBigDecimal(map.get("orderId")));
            omstruckOrder.setOrderStatus(new BigDecimal(3));
            //修改零星物资订单状态
            AmstruckSporadicOrder amstruckSporadicOrder=new AmstruckSporadicOrder();
            amstruckSporadicOrder.setSporadicOrderId(DataChange.dataToBigDecimal(map.get("sporadicOrderId")));
            amstruckSporadicOrder.setIssueStatus(new BigDecimal(1));
            result += amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
            result += omstruckOrderMapper.updateByPrimaryKeySelective(omstruckOrder);
        }
        return result;
    }

    /**
     * 逻辑删除零星物资订单
     * @param sporadicOrderId
     * @return
     */
    @Override
    public int deleteSporadicOrders(Integer sporadicOrderId) {
        int result = 0;
        AmstruckSporadicOrder amstruckSporadicOrder = amstruckSporadicOrderMapper.selectByPrimaryKey(new BigDecimal(sporadicOrderId));
        amstruckSporadicOrder.setDeleted(new BigDecimal(1));
        result += amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
        return result;
    }

    /**
     * 查询零星物资订单列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getSporadicOrdersList(Map<String, Object> mapValue) {
        List<Map<String, Object>> mapList=null;
        //apiId：439
        if (mapValue.get("sporadicStatus") != null) {
            //走查询订单id的接口
            mapList = amstruckSporadicOrderMapper.getSporadicOrdersList(mapValue);
        } else {
            //不查询订单id的接口
            mapList = amstruckSporadicMaterialMapper.getSporadicOrdersList4(mapValue);
        }
        for (Map<String, Object> map : mapList) {
            BigDecimal type = (BigDecimal) map.get("type");
            String orderType = "";
            if (type.intValue() == 12) {
                orderType += "零星进厂";
            }
            if (type.intValue() == 13) {
                orderType += "零星出厂";
            }
            if (type.intValue() == 14) {
                orderType += "中转";
            }
            if (type.intValue() == 19) {
                orderType += "退货";
            }
            map.put("orderType", orderType);
        }
        return mapList;
    }


    /**
     * 查询物资详情
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> seeAllMaterials(Map<String,Object> mapValue) {
        List<Map<String,Object>> mapList = amstruckSporadicOrderMapper.seeAllMaterials(mapValue);
        return mapList;
    }

    /**
     * 修改零星物资订单
     * @param mapValue
     * @return
     */
    @Override
    public int updateSporadicOrder(Map<String, Object> mapValue) {
        BigDecimal sporadicOrderId = new BigDecimal((Integer) mapValue.get("sporadicOrderId"));
        BigDecimal sendUnitId = new BigDecimal((Integer) mapValue.get("sendUnitId"));
        BigDecimal receiveUnitId = new BigDecimal((Integer) mapValue.get("receiveUnitId"));

        BigDecimal carrierId = new BigDecimal((Integer) mapValue.get("carrierId"));
        String userId =(String) mapValue.get("userId");
        AmstruckSporadicOrder amstruckSporadicOrder = amstruckSporadicOrderMapper.selectByPrimaryKey(sporadicOrderId);
        amstruckSporadicOrder.setSendUnitId(sendUnitId);
        amstruckSporadicOrder.setReceiveUnitId(receiveUnitId);
        if (carrierId!=null) {
            amstruckSporadicOrder.setCarrierId(carrierId);
        }
        amstruckSporadicOrder.setUpdateTime(new Date());
        amstruckSporadicOrder.setUpdateUsername(userId);
        int result = amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
        return result;
    }

    /**
     * 查询修改渲染
     * @param sporadicOrderId
     * @return
     */
    @Override
    public List<Map<String, Object>> selectSporadicOrder(Integer sporadicOrderId) {
        List<Map<String, Object>> mapList = amstruckSporadicOrderMapper.selectSporadicOrder(new BigDecimal(sporadicOrderId));
        return mapList;
    }




    //一车多趟
    @Override
    @Transactional
    public int addSporadicOrderforTimes(Map<String, Object> map) {
        int result=0;
        List<Map<String,Object>> maps= (List<Map<String, Object>>) map.get("mapList");
            for (Map<String,Object> map1:maps){
                Integer orderId =(Integer) map.get("orderId");
                Integer sporadicOrderId =(Integer) map.get("sporadicOrderId");
                String userId =(String) map1.get("userId");
                //修改零星订单下发状态
                AmstruckSporadicOrder amstruckSporadicOrder=new AmstruckSporadicOrder();
                amstruckSporadicOrder.setSporadicOrderId(DataChange.dataToBigDecimal(sporadicOrderId));
                amstruckSporadicOrder.setDispatchStatus(new BigDecimal(1));
                amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
                //根据运输订单id查找订单信息
                //生成新的订单
                OmstruckOrder omstruckOrder=new OmstruckOrder();
                //查找订单主表数据
                Map<String, Object> map2 = amstruckSporadicOrderMapper.selectOrderInfo(orderId);
                //查找订单子表数据
                List<Map<String,Object>>materialList =amstruckSporadicOrderMapper.selectOrderMaterial(orderId);
                BigDecimal carrierId =(BigDecimal) map2.get("carrierId");
                if (carrierId!=null){
                    omstruckOrder.setCarrierId(carrierId);
                }
                BigDecimal orderId1 = omstruckOrderMapper.selectMaxId();
                omstruckOrder.setOrderId(orderId1);
                omstruckOrder.setOrderPlanId(DataChange.dataToBigDecimal(map2.get("orderPlanId")));
                omstruckOrder.setOrderNumber(DataChange.generateEightDigitsNumber("WYSDD", orderId1.intValue()));
                //设置新增时间
                omstruckOrder.setInsertTime(new Date());
                omstruckOrder.setInsertUsername(userId);
                omstruckOrder.setLineId(DataChange.dataToBigDecimal(map2.get("lineId")));
                omstruckOrder.setOrderType(DataChange.dataToBigDecimal(map2.get("orderType")));
                result += omstruckOrderMapper.insertSelective(omstruckOrder);
                //新增总实绩id
                TmstruckTotalResult tmstruckTotalResult = new TmstruckTotalResult();
                tmstruckTotalResult.setResultTotalId(tmstruckTotalResultMapper.selectTmstruckTotalResultId());
                tmstruckTotalResult.setOrderId(omstruckOrder.getOrderId());
                tmstruckTotalResult.setInsertTime(new Date());
                tmstruckTotalResult.setInsertUsername(userId);
                result+=tmstruckTotalResultMapper.insertSelective(tmstruckTotalResult);
                //新增订单子表
                for (Map<String,Object>materialMap:materialList
                     ) {
                    OmstruckOrderMaterial omstruckOrderMaterial=new OmstruckOrderMaterial();
                    omstruckOrderMaterial.setOrderMaterialId(omstruckOrderMaterialMapper.selectMaxId());
                    omstruckOrderMaterial.setOrderId(omstruckOrder.getOrderId());
                    omstruckOrderMaterial.setMaterialId(DataChange.dataToBigDecimal(materialMap.get("materialId")));
                    omstruckOrderMaterial.setOrderMaterialNumber(DataChange.dataToBigDecimal(materialMap.get("materialNumber")));
                    omstruckOrderMaterial.setOrderMaterialWeight(DataChange.dataToBigDecimal(materialMap.get("materialWeight")));
                    omstruckOrderMaterial.setMaterialPriority(DataChange.dataToBigDecimal(materialMap.get("materialPriority")));
                    omstruckOrderMaterial.setInsertTime(new Date());
                    omstruckOrderMaterial.setInsertUsername(userId);
                    omstruckOrderMaterialMapper.insertSelective(omstruckOrderMaterial);
                }

                //设置运力id
                Integer capacityId = (Integer) map1.get("capacityId");
                omstruckOrder.setOrderId(orderId1);
                omstruckOrder.setCapacityId(DataChange.dataToBigDecimal(capacityId));
                //自动下发
                omstruckOrder.setOrderStatus(new BigDecimal(4));
                omstruckOrder.setOrderIssueTime(new Date());
                omstruckOrderMapper.updateByPrimaryKeySelective(omstruckOrder);
            }

        return result;
    }




    @Override
    public int closeSporadic(Map<String, Object> map) {
        int result = 0;
        BigDecimal sporadicOrderId = DataChange.dataToBigDecimal(map.get("sporadicOrderId"));
        AmstruckSporadicOrder amstruckSporadicOrder = new AmstruckSporadicOrder();
        amstruckSporadicOrder.setSporadicOrderId(sporadicOrderId);
        amstruckSporadicOrder.setSporadicOrderTimes(new BigDecimal(0));
        amstruckSporadicOrder.setTransStatus(new BigDecimal(0));
        result += amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
        return result;
    }
    //查看物资详情
    @Override
    public List<Map<String,Object>> getSporadic(Integer sporadicId) {
        return amstruckSporadicMaterialMapper.getSporadic(sporadicId);
    }

    //查询零星订单下的运输订单
    @Override
    public List<Map<String, Object>> getSporadicOfOrder(Map<String, Object> mapValue) {
        return amstruckSporadicMaterialMapper.getSporadicOfOrder(mapValue);
    }
}


